# Partial Access

Partial Access is a lightweight module for Drupal that displays **truncated content** to unauthorized users based on roles. Instead of using teasers or complex workflows, it limits access directly at the body field level and appends a **custom call-to-action (CTA)** for users without permission.

## Overview

This module provides:

- Truncated body field display for users without access.
- A configurable call-to-action message (e.g., "Subscribe to view full content").
- Role-based control over who sees full content.
- Site owners can place content created by specific user roles behind a **paywall barrier**.
- Simple configuration interface.

Use this module for:

- Premium blog previews
- Gated knowledge base or documentation
- Lead generation via call-to-action
- Member-only communities

## Requirements

- Drupal 11
- No external dependencies

## Installation

Install this module using the standard Drupal Composer-based workflow:

```sh
composer require drupal/partial_access
```

Then enable the module via Drush or the Drupal admin interface:

```sh
drush en partial_access
```

For general information on installing modules using Composer, refer to the official documentation:
📖 [Using Composer to manage Drupal site dependencies](https://www.drupal.org/docs/develop/using-composer/using-composer-to-manage-drupal-site-dependencies)

## Configuration

- Navigate to `Configuration → Partial Access Settings`.
- Select which roles should have full access to content.
- Set the CTA text for users without access.
- Truncation and display are applied automatically on node view.

## Recommended modules

These modules work well with Partial Access:
- [Webform](https://www.drupal.org/project/webform) – For custom subscription/contact forms
- [Block Visibility Groups](https://www.drupal.org/project/block_visibility_groups) – To show different CTAs per condition

## Similar projects

- [Content Access](https://www.drupal.org/project/content_access): Provides permission control but no partial display.
- Teaser-based view modes: More complex, require summary fields.

Partial Access stands out by working directly with the body field and being easy to configure.

## Maintainers

- [Chandraveer Singh](https://www.drupal.org/u/chandraveer-singh)
