<?php

namespace Drupal\partial_access\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for managing CTA button.
 */
class RestrictedContentConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['restricted_content.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'restricted_content_config_form';
  }

  /**
   * Build the form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('restricted_content.settings');
    $role_options = [];
    $roles = \Drupal::entityTypeManager()->getStorage('user_role')->loadMultiple();
    foreach ($roles as $role_id => $role) {
      $role_options[$role_id] = $role->label();
    }

    $form['cta_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('CTA Button Text'),
      '#default_value' => $config->get('cta_text') ?? 'Upgrade to Full Access',
      '#description' => $this->t('Set the text for the CTA button.'),
    ];

    $form['cta_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Redirect URL'),
      '#default_value' => $config->get('cta_url') ?? '/subscribe',
      '#description' => $this->t('Set the URL where users should be redirected.'),
    ];

    $form['restricted_roles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Roles restricted by paywall'),
      '#options' => $role_options,
      '#default_value' => $config->get('restricted_roles') ?? [],
      '#description' => $this->t('Select the roles whose content will be restricted by the paywall.'),
    ];

    $form['access_roles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Roles that can access restricted content'),
      '#options' => $role_options,
      '#default_value' => $config->get('access_roles') ?? [],
      '#description' => $this->t('Select the roles that can access the restricted content.'),
    ];

    // Body percentage to show before the paywall.
    $form['body_percentage'] = [
      '#type' => 'number',
      '#title' => $this->t('Body Percentage to Show'),
      '#default_value' => $config->get('body_percentage') ?? 50,
      '#min' => 0,
      '#max' => 100,
      '#description' => $this->t('Set the percentage of the body content to show before the paywall.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * Submit handler.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('restricted_content.settings')
      ->set('cta_text', $form_state->getValue('cta_text'))
      ->set('cta_url', $form_state->getValue('cta_url'))
      ->set('restricted_roles', array_filter($form_state->getValue('restricted_roles')))
      ->set('access_roles', array_filter($form_state->getValue('access_roles')))
      ->set('body_percentage', $form_state->getValue('body_percentage'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}